Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(744)

Unified Diff: webkit/plugins/npapi/plugin_utils.h

Issue 14099010: Move Version to base namespace. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome_frame/dll_redirector.h ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webkit/plugins/npapi/plugin_utils.h
diff --git a/webkit/plugins/npapi/plugin_utils.h b/webkit/plugins/npapi/plugin_utils.h
index 438e87955e9810c2f2d1713f9cc985c956cf50de..8fe1b13500423e3fb343043a7923b46186847738 100644
--- a/webkit/plugins/npapi/plugin_utils.h
+++ b/webkit/plugins/npapi/plugin_utils.h
@@ -8,16 +8,18 @@
#include "base/string16.h"
#include "webkit/plugins/webkit_plugins_export.h"
+namespace base {
class Version;
+}
namespace webkit {
namespace npapi {
// Parse a version string as used by a plug-in. This method is more lenient
// in accepting weird version strings than Version::GetFromString()
WEBKIT_PLUGINS_EXPORT void CreateVersionFromString(
const base::string16& version_string,
- Version* parsed_version);
+ base::Version* parsed_version);
// Returns true iff NPAPI plugins are supported on the current platform.
WEBKIT_PLUGINS_EXPORT bool NPAPIPluginsSupported();
« no previous file with comments | « chrome_frame/dll_redirector.h ('k') | no next file » | no next file with comments »
@@ -8,16 +8,18 @@
namespace npapi {
// Parse a version string as used by a plug-in. This method is more lenient
-// in accepting weird version strings than Version::GetFromString()
+// in accepting weird version strings than base::Version::GetFromString()
WEBKIT_PLUGINS_EXPORT void CreateVersionFromString(
const base::string16& version_string,

Powered by Google App Engine
This is Rietveld 408576698